@@ -55,6 +55,7 @@ def create_video(list_comp_data, path_video, job_id):
     print('get list')
     arr_comps=[]
     for comp_data in list_comp_data:
+        comp_data["job_id"]=job_id
         arr_comps.append(Component.convert(comp_data))
     arr_comps.sort(key=lambda obj: obj.index)
     arr_composite = []
@@ -136,6 +137,7 @@ def create_video(list_comp_data, path_video, job_id):
 
 class Component:
     def __init__(self, json_data):
+        self.job_id=json_data['job_id']
         self.index = json_data['index']
         self.position = json_data['position']
         self.start_time = json_data['startTime']
@@ -213,7 +215,7 @@ class CompilationComp(Component):
         self.music_data = json_data['music_data']
 
     def get_audio(self):
-        return MusicHelper.create_compilation_songs(self.music_data)
+        return MusicHelper.create_compilation_songs(self.music_data, self.job_id)
 
 
 class ElementComp(Component):
