@@ -102,7 +102,7 @@ def create_video_audio(clip_path, audio_path, rs_path=None, is_del=True):
     try:
         tmp_clip_path_z=rs_path
         if tmp_clip_path_z is None:
-            tmp_clip_path_z = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-final.avi'
+            tmp_clip_path_z = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-final.mp4'
         cmd = f"ffmpeg -i {clip_path} -i {audio_path} -vcodec copy -acodec copy -map 0:v -map 1:a -shortest -flags global_header -y {tmp_clip_path_z}"
         os.system(cmd)
         if is_del:
