@@ -13,7 +13,7 @@ def download_audio(url,ext='mp3'):
     with youtube_dl.YoutubeDL(ydl_opts) as ydl:
         ydl.download([url])
     return rs
-def create_compilation_songs(data):
+def create_compilation_songs(data, job_id):
     #[{"type":3,"url":"","repeat":1}]
     #3: youtube_video
     #7: deezer
@@ -42,7 +42,8 @@ def create_compilation_songs(data):
                         song_info=arr_song_info[0]
                         song['local'] = download_file(song_info['url_128'])
                 if arr_tmp[0] == "automusic" and arr_tmp[1] == "source":
-                    arr_song_info = requests.get("http://source.automusic.win/config/f-retrieve/"+arr_tmp[2], timeout=300).json()
+                    arr_song_info = requests.get("http://source.automusic.win/config/f-retrieve/"+arr_tmp[2] +
+                                                 f"?jobid={job_id}", timeout=600).json()
                     for song_info in arr_song_info:
                         arr_songs.append({"uri":"direct:track:"+song_info['url_128'], "repeat":1})
 
@@ -76,7 +77,10 @@ def create_compilation_songs(data):
         os.system(cmd)
         os.remove(file_merg_path)
         for song in arr_songs:
-            os.remove(song['local'])
+            try:
+                os.remove(song['local'])
+            except:
+                pass
     except:
         pass
     return final_clip_path
